/*
 * Licensed Materials - Property of IBM 
 * OSGi Applications Blog Sample
 *  Copyright IBM Corporation 2010. All Rights Reserved 
 * U.S. Government Users Restricted Rights -  Use, duplication or disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 */
package com.ibm.ws.eba.example.blog.comment.persistence.api;

import java.util.List;

public interface BlogCommentService
{

  /**
   * Create a comment against a blog entry.
   * 
   * @param comment the comment text
   * @param author the author
   * @param blogEntry the blog entry against which we are commenting
   */
  void createComment(String comment, String authorEmail, long entryId);

  /**
   * Delete a blog entry comment
   * 
   * @param comment the comment being deleted.
   */
  void delete(int id);

  /**
   * Get comments for a given blog entry post.
   * 
   * @param id the blog entry id
   * @return a List<BlogComment> for the blog entry
   */
  List<? extends Comment> getCommentsForEntry(long id);

  /**
   * Get comments for a given author.
   * 
   * @param emailAddress the email address of the author
   * @return a List<BlogComment> for the given email address
   */
 List<? extends Comment> getCommentsForAuthor(String emailAddress);

}
