/*
 * Licensed Materials - Property of IBM 
 * OSGi Applications Blog Sample
 *  Copyright IBM Corporation 2010. All Rights Reserved 
 * U.S. Government Users Restricted Rights -  Use, duplication or disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 */
package com.ibm.ws.eba.example.blog.comment.persistence;

import java.util.Date;
import java.util.List;

import javax.persistence.EntityManager;
import javax.persistence.PersistenceContext;
import javax.persistence.Query;

import com.ibm.ws.eba.example.blog.comment.persistence.api.BlogCommentService;
import com.ibm.ws.eba.example.blog.comment.persistence.entity.CommentImpl;
import com.ibm.ws.eba.example.blog.persistence.entity.AuthorImpl;
import com.ibm.ws.eba.example.blog.persistence.entity.EntryImpl;

/**
 * Implementation of the BlogCommentService
 */
public class BlogCommentServiceImpl implements BlogCommentService
{
  // Annotation scanning injects in the EntityManager, the
  // persistence unit definition can be found in the persistence.xml
  // associated with this bundle.
	private EntityManager em;
  @PersistenceContext(unitName = "blogExample")
	public void setEntityManager(EntityManager e) {
		em = e;
	}
  
  
  synchronized public void createComment(String comment, String authorEmail, long id)
  {
	EntryImpl entry = em.find(EntryImpl.class, id);
	AuthorImpl author = em.find(AuthorImpl.class, authorEmail);
    CommentImpl c = new CommentImpl();
    c.setAuthor(author);
    c.setEntry(entry);
    c.setComment(comment);
    c.setCreationDate(new Date(System.currentTimeMillis()));
    em.persist(c);
  }

  synchronized public void delete(int id)
  {
    em.remove(em.find(CommentImpl.class, id));
  }

  @SuppressWarnings("unchecked")
  synchronized public List<CommentImpl> getCommentsForAuthor(String emailAddress)
  {
    Query q = em.createQuery("SELECT c FROM COMMENT c WHERE c.author.email = :addr");
    q.setParameter("addr", emailAddress);
    return q.getResultList();
  }

  @SuppressWarnings("unchecked")
  synchronized public List<CommentImpl> getCommentsForEntry(long id)
  {
    Query q = em.createQuery("SELECT c FROM COMMENT c WHERE c.blogentry.id = :id");
    q.setParameter("id", id);
    return q.getResultList();
  }
}
