/*
 * Licensed Materials - Property of IBM 
 * OSGi Applications Blog Sample
 *  Copyright IBM Corporation 2010. All Rights Reserved 
 * U.S. Government Users Restricted Rights -  Use, duplication or disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 */
package com.ibm.ws.eba.example.blog.web;

import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;

import com.ibm.ws.eba.example.blog.api.BloggingService;
import com.ibm.ws.eba.example.blog.web.util.JNDIHelper;

public class AddComment extends HttpServlet {
	private static final long serialVersionUID = -920234218060948564L;
	public static final String ERROR_MESSAGES_ID = "commentErrorMessages";

	@Override
	protected void doGet(HttpServletRequest req, HttpServletResponse resp)
			throws ServletException, IOException {

		// email address of the comment's author
		String email = req.getParameter("email");
		// the id of the blog entry to which this comment is associated
		long postId = Long.parseLong(req.getParameter("postId"));
		// the text of the comment
		String text = req.getParameter("text");
		
		BloggingService service = JNDIHelper.getBloggingService();

		// retrieve the blog entry and create the associated comment
        email = ValidationUtils.processInputData( email );
		text = ValidationUtils.processHTML( text );
        
        if( !ValidationUtils.isValidName( email ) )
        {
        	addError(req, "An invalid email was specified.");
			resp.sendRedirect("AddCommentForm?postId=" + postId);        	
        }
        else if (service.getBlogAuthor(email) != null) 
        {
			service.createBlogComment(text, email, postId);
			resp.sendRedirect("ViewBlog");
		} 
        else 
		{

			if (email.equals(""))
				addError(req, "The email field is required.");
			else
				addError(req, "The email filed is not valid.");
			
			resp.sendRedirect("AddCommentForm?postId=" + postId);
		}
	}

	public static void addError(HttpServletRequest req, String error) {
		HttpSession session = req.getSession();
		if (session != null) {
			@SuppressWarnings("unchecked")
			List<String> errors = (List<String>) session
					.getAttribute(ERROR_MESSAGES_ID);

			if (errors == null) {
				errors = new ArrayList<String>();
				session.setAttribute(ERROR_MESSAGES_ID, errors);
			}

			errors.add(error);
		}
	}
}