/*
 * Licensed Materials - Property of IBM 
 * OSGi Applications Blog Sample
 *  Copyright IBM Corporation 2010. All Rights Reserved 
 * U.S. Government Users Restricted Rights -  Use, duplication or disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 */
package com.ibm.ws.eba.example.blog.web;

import java.io.IOException;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import com.ibm.ws.eba.example.blog.api.BloggingService;
import com.ibm.ws.eba.example.blog.web.util.FormServlet;
import com.ibm.ws.eba.example.blog.web.util.JNDIHelper;

public class CreateBlogEntry extends HttpServlet
{
  private static final long serialVersionUID = -6484228320837122235L;

  @Override
  protected void doGet(HttpServletRequest req, HttpServletResponse resp) throws ServletException,
      IOException{
        doPost(req,resp);
  }
  
  @Override
  protected void doPost(HttpServletRequest req, HttpServletResponse resp) throws ServletException,
      IOException
  {
    // new blog entry values
    String email = req.getParameter("email");
    String title = req.getParameter("title");
    String text = req.getParameter("text");
    String tags = req.getParameter("tags");
    
    BloggingService service = JNDIHelper.getBloggingService();
    
    email = ValidationUtils.processInputData( email );
    title = ValidationUtils.processInputData( title );
    tags  = ValidationUtils.processInputData( tags );
    text  = ValidationUtils.processHTML( text );
    
    if (service.getBlogAuthor(email) != null) 
    {
      service.createBlogEntry(email, title, text, tags);
      resp.sendRedirect("ViewBlog");
    } 
    else 
    {
      storeParam(req, "title", title);
      storeParam(req, "email", email);
      storeParam(req, "tags", tags);     
      storeParam(req, "text", text);
      
      if( !ValidationUtils.isValidName( email ) )
      {
    	  FormServlet.addError(req, "An invalid email was specified.");
      }
      else if (email.equals(""))
        FormServlet.addError(req, "The email field is required.");
      else
        FormServlet.addError(req, "The author's email is not valid.");
      
      resp.sendRedirect("CreateBlogEntryForm");
    }
  }
  
  private void storeParam(HttpServletRequest req, String param, String value) 
  {
    FormServlet.storeParam(req, CreateBlogEntryForm.ID, param, value);
  }
}