/*
 * Licensed Materials - Property of IBM 
 * OSGi Applications Blog Sample
 *  Copyright IBM Corporation 2010. All Rights Reserved 
 * U.S. Government Users Restricted Rights -  Use, duplication or disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 */
package com.ibm.ws.eba.example.blog.web;

import java.io.IOException;

import javax.servlet.RequestDispatcher;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import com.ibm.ws.eba.example.blog.api.BloggingService;
import com.ibm.ws.eba.example.blog.web.util.FormServlet;
import com.ibm.ws.eba.example.blog.web.util.JNDIHelper;

public class EditAuthor extends HttpServlet
{
  private static final long serialVersionUID = -8881545878284864977L;

  @Override
  protected void doGet(HttpServletRequest req, HttpServletResponse resp) throws ServletException, IOException
  {
    doPost(req, resp);
  }
  
  @Override
  protected void doPost(HttpServletRequest req, HttpServletResponse resp) throws ServletException,
      IOException
  {
    // This method will update or create an author depending on the
    // existence of the author in the database.
    
    // The authors email address is the key in the database, thus if
    // the email address is not in the database we create this as a 
    // new author.
    
    String email = req.getParameter("email");
    String nickName = req.getParameter("nickName");
    String name = req.getParameter("name");
    String bio = req.getParameter("bio");
    String dob = req.getParameter("dob");
    
    email    = ValidationUtils.processInputData( email );
    nickName = ValidationUtils.processInputData( nickName );
    name     = ValidationUtils.processInputData( name );
    bio      = ValidationUtils.processInputData( bio );
    dob      = ValidationUtils.processInputData( dob );

    if (email == null || email.equals("")) {
      storeParam(req, "email", email);
      storeParam(req, "nickName", nickName);
      storeParam(req, "name", name);
      storeParam(req, "bio", bio);
      storeParam(req, "dob", dob);
      
      FormServlet.addError(req, "The email field is required.");
      resp.sendRedirect("EditAuthorForm");
    } 
    else if( !ValidationUtils.isValidName( email ) )
    {
        storeParam(req, "nickName", nickName);
        storeParam(req, "name", name);
        storeParam(req, "bio", bio);
        storeParam(req, "dob", dob);
    	FormServlet.addError(req, "An invalid email was specified.");
		resp.sendRedirect("EditAuthorForm");        	
    }
    else if( !ValidationUtils.isValidDate( dob ) )
    {
        storeParam(req, "email", email);
        storeParam(req, "nickName", nickName);
        storeParam(req, "name", name);
        storeParam(req, "bio", bio);
    	FormServlet.addError(req, "An invalid date was specified.");
		resp.sendRedirect("EditAuthorForm");        		
    }
    else 
    {
      BloggingService service = JNDIHelper.getBloggingService();

      if (service.getBlogAuthor(email) != null) {
        // do an update
        service.updateBlogAuthor(email, nickName, name, bio, dob);
      } else {
        // do a create
        service.createBlogAuthor(email, nickName, name, bio, dob);
      }
      
      RequestDispatcher dispatch = getServletContext().getRequestDispatcher("ViewAuthor");
      dispatch.forward(req, resp);
    }
  }
  
    private void storeParam(HttpServletRequest req, String param, String value) 
  {
    FormServlet.storeParam(req, EditAuthorForm.ID, param, value);
  }
}