package com.ibm.ws.eba.example.blog.web;

import java.util.regex.Matcher;
import java.util.regex.Pattern;

public class ValidationUtils 
{
  private static Pattern  pattern = Pattern.compile("^[A-Za-z0-9_\\-@\\.]+$");
  private static Pattern  datePattern = Pattern.compile( "^\\d\\d\\d\\d\\-\\d\\d-\\d\\d$" );
  private static String   specialChars = "[<>\\{\\}\\[\\];\\&\\)\\(]";

  public static String processInputData( String value )
  {
    return value == null ? null : value.replaceAll( specialChars, " " );	  
  }
  
  public static boolean hasSpecialCharacter( String value )
  {
	return value.matches( ".*" + specialChars + ".*" );
  }
  
  public static String processHTML( String value )
  {
    // Allow all html with one or two letter.
	value = value.replaceAll( "<([a-zA-Z]{1,2})>", "##$1##" );
	value = value.replaceAll( "</([a-zA-Z]{1,2})>", "##!$1##" );
	value = processInputData( value );
	value = value.replaceAll( "##([a-zA-Z]{1,2})##", "<$1>" );
	value = value.replaceAll( "##!([a-zA-Z]{1,2})##", "<\\/$1>" );
	
	return value;
  }
  
  public static void main( String[] args )
  {
	String value = processHTML( "<p>hello</p><li></li><body><p onMouseOver=>" );
	
	System.out.println( "value=" + value + "end" );
  }
  
  public static boolean isValidDate( String date )
  {
	if( date == null ) return false;
	
	return datePattern.matcher( date ).matches();
  }
  
  public static boolean isValidString( String toValidate ) 
  {
    return (toValidate != null && toValidate.length() > 0);
  }

  public static boolean isValidName( String name ) 
  {
	if( !isValidString(name) ) return false;
		
	Matcher matcher = pattern.matcher(name);	
	boolean result  = matcher.matches();
	
	return result;
  }
}
