/*
 * Licensed Materials - Property of IBM 
 * OSGi Applications Blog Sample
 *  Copyright IBM Corporation 2010. All Rights Reserved 
 * U.S. Government Users Restricted Rights -  Use, duplication or disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 */
package com.ibm.ws.eba.example.blog.web.util;

import java.io.PrintWriter;
import java.util.ArrayList;
import java.util.Collection;

import com.ibm.json.java.JSONObject;

/**
 * Utility class to provide html headers, footers, 
 * dojo use and blogging service.
 */
public class HTMLOutput
{
  private static final String dojoAPI = "http://ajax.googleapis.com/ajax/libs/dojo/1.4/";
  public static final void writeHTMLHeaderPartOne(PrintWriter out, String pageTitle)
  {
    out.println("<html>");
    out.println("\t<head>");
    out.print("\t\t<title>");
    out.print(pageTitle);
    out.println("</title>");

    out.println("<link rel=\"Stylesheet\" href=\"style/blog.css\" type=\"text/css\" media=\"screen\"/>");
  }
    
  public static final void writeDojoUses(PrintWriter out, String ... modules)
  {
    out.println("<link rel=\"Stylesheet\" href=\"" + dojoAPI + "dijit/themes/tundra/tundra.css\" type=\"text/css\" media=\"screen\"/>");
    out.println("<link rel=\"Stylesheet\" href=\"" + dojoAPI + "dijit/themes/nihilo/nihilo.css\" type=\"text/css\" media=\"screen\"/>");
    out.println("<link rel=\"Stylesheet\" href=\"" + dojoAPI + "dijit/themes/soria/soria.css\" type=\"text/css\" media=\"screen\"/>");
    out.println("<link rel=\"Stylesheet\" href=\"" + dojoAPI + "dojo/resources/dojo.css\" type=\"text/css\" media=\"screen\"/>");
	  
    out.println("<script type=\"text/javascript\" src=\"" + dojoAPI + "dojo/dojo.xd.js\" djConfig=\"parseOnLoad: true\"></script>");
    out.println("<script type=\"text/javascript\">");
    out.println("dojo.require(\"dojo.parser\");");
    
    for (String module : modules) {
      out.print("dojo.require(\"");
      out.print(module);
      out.println("\");");
    }
    
    out.println("</script>");
  }
  
  public static final void writeHTMLHeaderPartTwo(PrintWriter out)
  {
    writeHTMLHeaderPartTwo(out, new ArrayList<String>());
  }
  
  public static final void writeHTMLHeaderPartTwo(PrintWriter out, Collection<String> errorMessages)
  {
    // Whilst this is a pretty useless piece of code this JSONObject is here
    // to demonstrate bundle sharing between applications as both samples use
    // the JSON bundle from the internal bundle repository
    JSONObject obj = new JSONObject();
    obj.put("Title", "Blog Home");
    String heading = (String) obj.get("Title");
    
    out.println("\t</head>");
    out.println("\t<body class=\"soria\">");
    out.println("\t\t<div id=\"content\" class=\"content\">");
    out.println("\t\t\t<div id=\"header\">");
    out.println("\t\t\t\t<p><a href=\"ViewBlog\" style=\"text-decoration: none; color: white\">"+heading+"</a></p>");
    out.println("\t\t\t</div>");
    
    if (!!!errorMessages.isEmpty()) {
      out.println("\t\t\t<div id=\"errorMessages\">");
      for (String msg : errorMessages) {
        out.println("\t\t\t\t<div class=\"errorMessage\">" + msg + "</div>");
      }
      out.println("\t\t\t</div>");
    }
    
    out.println("\t\t\t<div id=\"mainContent\" class=\"mainContent\">");    
  }
  
  public static final void writeHTMLFooter(PrintWriter out)
  {
    out.println("\t\t\t</div>");
    out.println("\t\t\t<div id=\"footer\">");
    out.println("\t\t\t</div>");
    out.println("\t\t</div>");
    out.println("\t</body>");
    out.println("</html>");
  }
  
}