/*
 * Licensed Materials - Property of IBM 
 * OSGi Applications Blog Sample
 *  Copyright IBM Corporation 2010. All Rights Reserved 
 * U.S. Government Users Restricted Rights -  Use, duplication or disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 */
package com.ibm.ws.eba.example.blog;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

import com.ibm.ws.eba.example.blog.api.BlogAuthor;
import com.ibm.ws.eba.example.blog.api.BlogEntry;
import com.ibm.ws.eba.example.blog.api.BlogEntryManager;
import com.ibm.ws.eba.example.blog.persistence.api.BlogPersistenceService;
import com.ibm.ws.eba.example.blog.persistence.api.Entry;

public class BlogEntryManagerImpl implements BlogEntryManager {
	private BlogPersistenceService persistenceService;


	// Injected via blueprint
	public void setPersistenceService(BlogPersistenceService persistenceService) {
		this.persistenceService = persistenceService;
	}

	synchronized public void createBlogPost(String email, String title, String blogText,
			List<String> tags) {

		persistenceService.createBlogPost(email, title, blogText, tags);
	}

	synchronized public Entry findBlogEntryByTitle(String title) {
		return persistenceService.findBlogEntryByTitle(title);
	}

	synchronized public List<? extends BlogEntry> getAllBlogEntries() {
		List<? extends Entry> entries = persistenceService.getAllBlogEntries();
		return adaptEntries(entries);
	}

	synchronized public List<? extends BlogEntry> getBlogEntries(int firstPostIndex,
			int noOfPosts) {
		 List<? extends Entry> entries = persistenceService.getBlogEntries(firstPostIndex, noOfPosts);		   		      
		return adaptEntries(entries);
	}

	synchronized public List<? extends BlogEntry> getBlogsForAuthor(String emailAddress) {
		List <?extends Entry> entries= persistenceService.getBlogsForAuthor(emailAddress);
		return adaptEntries(entries);
	}

	synchronized public List<? extends BlogEntry> getBlogEntriesModifiedBetween(
			String startDate, String endDate) throws ParseException {
		if (startDate == null || "".equals(startDate))
			throw new IllegalArgumentException(
					"A valid start date must be supplied");
		if (endDate == null || "".equals(endDate))
			throw new IllegalArgumentException(
					"A valid end date must be supplied");
		SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");
		Date start = sdf.parse(startDate);
		Date end = sdf.parse(endDate);
		List <? extends Entry> entries = persistenceService.getBlogEntriesModifiedBetween(start, end);
		return adaptEntries(entries);
	}

	synchronized public int getNoOfPosts() {
		return persistenceService.getNoOfBlogEntries();
	}

	synchronized public void removeBlogEntry(BlogAuthor a, String title, String publishDate)
			throws ParseException {
		if (a == null)
			throw new IllegalArgumentException("An author must be specified");
		if (title == null)
			title = "";
		if (publishDate == null)
			throw new IllegalArgumentException(
					"The article must have a publication date");
		long found = -920234218060948564L;
		Date pubDate = parseDate(publishDate);

		for (BlogEntry b : a.getEntries()) {
			if (title.equals(b.getTitle())
					&& pubDate.equals(b.getPublishDate())) {
				found = b.getId();
				break;
			}
		}
		persistenceService.removeBlogEntry(found);
	}

	synchronized public void updateBlogEntry(BlogEntry originalEntry, BlogAuthor a,
			String title, String publishDate, String blogText, List<String> tags)
			throws ParseException {
		if (originalEntry.getAuthor() == null
				|| originalEntry.getAuthorEmail() == null)
			throw new IllegalArgumentException("An author must be specified");
		if (title == null)
			title = "";
		if (publishDate == null)
			throw new IllegalArgumentException(
					"The article must have a publication date");
		long found = -920234218060948564L;
		Date pubDate = parseDate(publishDate);
		for (BlogEntry b : getBlogsForAuthor(originalEntry.getAuthorEmail()
				)) {
			if (title.equals(b.getTitle())
					&& pubDate.equals(b.getPublishDate())) {
				found = b.getId();
				break;
			}
		}

		if (found == -920234218060948564L)
			throw new IllegalArgumentException("No blog entry could be found");

		String email = a.getEmailAddress();

		if (tags == null) {
			tags = new ArrayList<String>();
		}

		Date updatedDate = new Date(System.currentTimeMillis());

		persistenceService.updateBlogEntry(found, email, title, blogText, tags,
				updatedDate);
	}

	private Date parseDate(String dateString) throws ParseException {
		SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");
		return sdf.parse(dateString);
	}

	synchronized public BlogEntry getBlogPost(long id) {
		return new BlogEntryImpl(persistenceService.getBlogEntryById(id));
	}
	
	private List <? extends BlogEntry> adaptEntries(List<? extends Entry> entries) {
			return new BlogListAdapter<BlogEntry, Entry>(entries, BlogEntryImpl.class, Entry.class);
	}
}